Contributors
------------

A huge thank you to **Brodie Rao** for coming up with, and sharing
Cram_ with all of us. For sure this tool saved a lot of people
a lot of debugging.

So once more, **Tank you Brodie!**

Also a big thank you, to everybody which took the time, to improve cram
and/or frysk.

So without further ado, the contributors:

* **Brodie Rao** (Author of Cram_)
* Nicola Coretti (Maintainer & Initiator of frysk_)
* Steve Losh
* Alexander Solovyov
* Daniel Hahler
* Andrey Vlasovskikh
* Mehul Kar
* Nigel Stewart
* kdreyer-redhat
* Cédric Duval
* Douglas Creager
* Kamil Kisiel
* PJ Eby
* Petri Lehtinen
* Fahmi Ghediri
* Larsson Rasmus

The most up to date list you'll find on Github_ though.


.. _Github: https://github.com/Nicoretti/frysk/graphs/contributors
.. _Cram: https://github.com/brodie/cram
.. _frysk: https://github.com/Nicoretti/frysk
